==> ejc-hrmanage-api-3.0.0-20240620.093841-67-sources.jar: com/ejianc/business/hr/vo/AttendanceMonthVO.java <==
package com.ejianc.business.hr.vo;


import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 人员考勤月度明细
 *
 * @author generator
 */
public class AttendanceMonthVO extends UserDataVO{

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date serviceDate;//统计时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date attendanceDate;//年月标识
    private BigDecimal shouldDay;//应出勤天数
    private BigDecimal actualDay;//实际出勤天数
    private Integer totalNum;//次数
    private BigDecimal thingLeave;//事假
    private BigDecimal sickLeave;//病假
    private BigDecimal yearLeave;//年假
    private BigDecimal marriageLeave;//婚假
    private BigDecimal workInjuryLeave;//工伤假
    private BigDecimal maternityLeave;//产假
    private BigDecimal bereaveLeave;//丧假
    private BigDecimal totalLate;//累计迟到
    private BigDecimal totalLeaveEarly;//累计旱退
    private BigDecimal totalAbsent;//旷工
    private BigDecimal workOverTime;//平时加班
    private BigDecimal holidayWorkTime;//公休日加班
    private BigDecimal sundayWorkTime;//节假日加班
    private String workDay;//工作日期
    private BigDecimal nursingLeave;//护理假
    private BigDecimal lateNum;//迟到次数
    private BigDecimal leaveEarlyNum;//早退次数
    private BigDecimal absentNum;//未签到次数
    private BigDecimal outWork;//外勤
    private BigDecimal outBusiness;//出差
    private BigDecimal localOutBusiness;//本地出差

    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }

    public Date getAttendanceDate() {
        return attendanceDate;
    }

    public void setAttendanceDate(Date attendanceDate) {
        this.attendanceDate = attendanceDate;
    }

    public BigDecimal getShouldDay() {
        return shouldDay;
    }

    public void setShouldDay(BigDecimal shouldDay) {
        this.shouldDay = shouldDay;
    }

    public BigDecimal getActualDay() {
        return actualDay;
    }

    public void setActualDay(BigDecimal actualDay) {
        this.actualDay = actualDay;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public BigDecimal getThingLeave() {
        return thingLeave;
    }

    public void setThingLeave(BigDecimal thingLeave) {
        this.thingLeave = thingLeave;
    }

    public BigDecimal getSickLeave() {
        return sickLeave;
    }

    public void setSickLeave(BigDecimal sickLeave) {
        this.sickLeave = sickLeave;
    }

    public BigDecimal getYearLeave() {
        return yearLeave;
    }

    public void setYearLeave(BigDecimal yearLeave) {
        this.yearLeave = yearLeave;
    }

    public BigDecimal getMarriageLeave() {
        return marriageLeave;
    }

    public void setMarriageLeave(BigDecimal marriageLeave) {
        this.marriageLeave = marriageLeave;
    }

    public BigDecimal getWorkInjuryLeave() {
        return workInjuryLeave;
    }

    public void setWorkInjuryLeave(BigDecimal workInjuryLeave) {
        this.workInjuryLeave = workInjuryLeave;
    }

    public BigDecimal getMaternityLeave() {
        return maternityLeave;
    }

    public void setMaternityLeave(BigDecimal maternityLeave) {
        this.maternityLeave = maternityLeave;
    }

    public BigDecimal getBereaveLeave() {
        return bereaveLeave;
    }

    public void setBereaveLeave(BigDecimal bereaveLeave) {
        this.bereaveLeave = bereaveLeave;
    }

    public BigDecimal getTotalLate() {
        return totalLate;
    }

    public void setTotalLate(BigDecimal totalLate) {
        this.totalLate = totalLate;
    }

    public BigDecimal getTotalLeaveEarly() {
        return totalLeaveEarly;
    }

    public void setTotalLeaveEarly(BigDecimal totalLeaveEarly) {
        this.totalLeaveEarly = totalLeaveEarly;
    }

    public BigDecimal getTotalAbsent() {
        return totalAbsent;
    }

    public void setTotalAbsent(BigDecimal totalAbsent) {
        this.totalAbsent = totalAbsent;
    }

    public BigDecimal getWorkOverTime() {
        return workOverTime;
    }

    public void setWorkOverTime(BigDecimal workOverTime) {
        this.workOverTime = workOverTime;
    }

    public BigDecimal getHolidayWorkTime() {
        return holidayWorkTime;
    }

    public void setHolidayWorkTime(BigDecimal holidayWorkTime) {
        this.holidayWorkTime = holidayWorkTime;
    }

    public BigDecimal getSundayWorkTime() {
        return sundayWorkTime;
    }

    public void setSundayWorkTime(BigDecimal sundayWorkTime) {
        this.sundayWorkTime = sundayWorkTime;
    }

    public String getWorkDay() {
        return workDay;
    }

    public void setWorkDay(String workDay) {
        this.workDay = workDay;
    }

    public BigDecimal getNursingLeave() {
        return nursingLeave;
    }

    public void setNursingLeave(BigDecimal nursingLeave) {
        this.nursingLeave = nursingLeave;
    }

    public BigDecimal getLateNum() {
        return lateNum;
    }

    public void setLateNum(BigDecimal lateNum) {
        this.lateNum = lateNum;
    }

    public BigDecimal getLeaveEarlyNum() {
        return leaveEarlyNum;
    }

    public void setLeaveEarlyNum(BigDecimal leaveEarlyNum) {
        this.leaveEarlyNum = leaveEarlyNum;
    }

    public BigDecimal getAbsentNum() {
        return absentNum;
    }

    public void setAbsentNum(BigDecimal absentNum) {
        this.absentNum = absentNum;
    }

    public BigDecimal getOutWork() {
        return outWork;
    }

    public void setOutWork(BigDecimal outWork) {
        this.outWork = outWork;
    }

    public BigDecimal getOutBusiness() {
        return outBusiness;
    }

    public void setOutBusiness(BigDecimal outBusiness) {
        this.outBusiness = outBusiness;
    }

    public BigDecimal getLocalOutBusiness() {
        return localOutBusiness;
    }

    public void setLocalOutBusiness(BigDecimal localOutBusiness) {
        this.localOutBusiness = localOutBusiness;
    }
}

==> ejc-hrmanage-api-3.0.0-20240911.081358-148-sources.jar: com/ejianc/business/hr/vo/AttendanceMonthVO.java <==
package com.ejianc.business.hr.vo;


import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 人员考勤月度明细
 *
 * @author generator
 */
public class AttendanceMonthVO extends UserDataVO{

    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date serviceDate;//统计时间
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date attendanceDate;//年月标识
    private BigDecimal shouldDay;//应出勤天数
    private BigDecimal actualDay;//实际出勤天数
    private Integer totalNum;//次数
    private BigDecimal thingLeave;//事假
    private BigDecimal sickLeave;//病假
    private BigDecimal yearLeave;//年假
    private BigDecimal marriageLeave;//婚假
    private BigDecimal workInjuryLeave;//工伤假
    private BigDecimal maternityLeave;//产假
    private BigDecimal bereaveLeave;//丧假
    private BigDecimal totalLate;//累计迟到
    private BigDecimal totalLeaveEarly;//累计旱退
    private BigDecimal totalAbsent;//旷工
    private BigDecimal workOverTime;//平时加班
    private BigDecimal holidayWorkTime;//公休日加班
    private BigDecimal sundayWorkTime;//节假日加班
    private String workDay;//工作日期
    private BigDecimal nursingLeave;//护理假
    private BigDecimal lateNum;//迟到次数
    private BigDecimal leaveEarlyNum;//早退次数
    private BigDecimal absentNum;//未签到次数
    private BigDecimal outWork;//外勤
    private BigDecimal outBusiness;//出差
    private BigDecimal localOutBusiness;//本地出差

    private BigDecimal sum;//合计总人数
    private String attendanceYearMonth;//考勤年月
    private String orgSequence;//组织排序

    @Override
    public String getOrgSequence() {
        return orgSequence;
    }

    @Override
    public void setOrgSequence(String orgSequence) {
        this.orgSequence = orgSequence;
    }

    public BigDecimal getSum() {
        return sum;
    }

    public void setSum(BigDecimal sum) {
        this.sum = sum;
    }

    public String getAttendanceYearMonth() {
        return attendanceYearMonth;
    }

    public void setAttendanceYearMonth(String attendanceYearMonth) {
        this.attendanceYearMonth = attendanceYearMonth;
    }

    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }

    public Date getAttendanceDate() {
        return attendanceDate;
    }

    public void setAttendanceDate(Date attendanceDate) {
        this.attendanceDate = attendanceDate;
    }

    public BigDecimal getShouldDay() {
        return shouldDay;
    }

    public void setShouldDay(BigDecimal shouldDay) {
        this.shouldDay = shouldDay;
    }

    public BigDecimal getActualDay() {
        return actualDay;
    }

    public void setActualDay(BigDecimal actualDay) {
        this.actualDay = actualDay;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public BigDecimal getThingLeave() {
        return thingLeave;
    }

    public void setThingLeave(BigDecimal thingLeave) {
        this.thingLeave = thingLeave;
    }

    public BigDecimal getSickLeave() {
        return sickLeave;
    }

    public void setSickLeave(BigDecimal sickLeave) {
        this.sickLeave = sickLeave;
    }

    public BigDecimal getYearLeave() {
        return yearLeave;
    }

    public void setYearLeave(BigDecimal yearLeave) {
        this.yearLeave = yearLeave;
    }

    public BigDecimal getMarriageLeave() {
        return marriageLeave;
    }

    public void setMarriageLeave(BigDecimal marriageLeave) {
        this.marriageLeave = marriageLeave;
    }

    public BigDecimal getWorkInjuryLeave() {
        return workInjuryLeave;
    }

    public void setWorkInjuryLeave(BigDecimal workInjuryLeave) {
        this.workInjuryLeave = workInjuryLeave;
    }

    public BigDecimal getMaternityLeave() {
        return maternityLeave;
    }

    public void setMaternityLeave(BigDecimal maternityLeave) {
        this.maternityLeave = maternityLeave;
    }

    public BigDecimal getBereaveLeave() {
        return bereaveLeave;
    }

    public void setBereaveLeave(BigDecimal bereaveLeave) {
        this.bereaveLeave = bereaveLeave;
    }

    public BigDecimal getTotalLate() {
        return totalLate;
    }

    public void setTotalLate(BigDecimal totalLate) {
        this.totalLate = totalLate;
    }

    public BigDecimal getTotalLeaveEarly() {
        return totalLeaveEarly;
    }

    public void setTotalLeaveEarly(BigDecimal totalLeaveEarly) {
        this.totalLeaveEarly = totalLeaveEarly;
    }

    public BigDecimal getTotalAbsent() {
        return totalAbsent;
    }

    public void setTotalAbsent(BigDecimal totalAbsent) {
        this.totalAbsent = totalAbsent;
    }

    public BigDecimal getWorkOverTime() {
        return workOverTime;
    }

    public void setWorkOverTime(BigDecimal workOverTime) {
        this.workOverTime = workOverTime;
    }

    public BigDecimal getHolidayWorkTime() {
        return holidayWorkTime;
    }

    public void setHolidayWorkTime(BigDecimal holidayWorkTime) {
        this.holidayWorkTime = holidayWorkTime;
    }

    public BigDecimal getSundayWorkTime() {
        return sundayWorkTime;
    }

    public void setSundayWorkTime(BigDecimal sundayWorkTime) {
        this.sundayWorkTime = sundayWorkTime;
    }

    public String getWorkDay() {
        return workDay;
    }

    public void setWorkDay(String workDay) {
        this.workDay = workDay;
    }

    public BigDecimal getNursingLeave() {
        return nursingLeave;
    }

    public void setNursingLeave(BigDecimal nursingLeave) {
        this.nursingLeave = nursingLeave;
    }

    public BigDecimal getLateNum() {
        return lateNum;
    }

    public void setLateNum(BigDecimal lateNum) {
        this.lateNum = lateNum;
    }

    public BigDecimal getLeaveEarlyNum() {
        return leaveEarlyNum;
    }

    public void setLeaveEarlyNum(BigDecimal leaveEarlyNum) {
        this.leaveEarlyNum = leaveEarlyNum;
    }

    public BigDecimal getAbsentNum() {
        return absentNum;
    }

    public void setAbsentNum(BigDecimal absentNum) {
        this.absentNum = absentNum;
    }

    public BigDecimal getOutWork() {
        return outWork;
    }

    public void setOutWork(BigDecimal outWork) {
        this.outWork = outWork;
    }

    public BigDecimal getOutBusiness() {
        return outBusiness;
    }

    public void setOutBusiness(BigDecimal outBusiness) {
        this.outBusiness = outBusiness;
    }

    public BigDecimal getLocalOutBusiness() {
        return localOutBusiness;
    }

    public void setLocalOutBusiness(BigDecimal localOutBusiness) {
        this.localOutBusiness = localOutBusiness;
    }
}
